==> kadaster-gds2-1.2-sources.jar: nl/kadaster/schemas/gds2/service/afgifte_bestandophalen/v20130701/BestandOphalenRequest.java <==

package nl.kadaster.schemas.gds2.service.afgifte_bestandophalen.v20130701;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import nl.kadaster.schemas.gds2.afgifte_bestandophalen.v20120901.BestandOphalenType;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="verzoek" type="{http://www.kadaster.nl/schemas/gds2/afgifte-bestandophalen/v20120901}BestandOphalenType"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "verzoek"
})
@XmlRootElement(name = "BestandOphalenRequest")
public class BestandOphalenRequest {

    @XmlElement(required = true)
    protected BestandOphalenType verzoek;

    /**
     * Gets the value of the verzoek property.
     * 
     * @return
     *     possible object is
     *     {@link BestandOphalenType }
     *     
     */
    public BestandOphalenType getVerzoek() {
        return verzoek;
    }

    /**
     * Sets the value of the verzoek property.
     * 
     * @param value
     *     allowed object is
     *     {@link BestandOphalenType }
     *     
     */
    public void setVerzoek(BestandOphalenType value) {
        this.verzoek = value;
    }

}

==> kadaster-gds2-2.0-sources.jar: nl/kadaster/schemas/gds2/service/afgifte_bestandophalen/v20130701/BestandOphalenRequest.java <==

package nl.kadaster.schemas.gds2.service.afgifte_bestandophalen.v20130701;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import nl.kadaster.schemas.gds2.afgifte_bestandophalen.v20120901.BestandOphalenType;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType&gt;
 *   &lt;complexContent&gt;
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *       &lt;sequence&gt;
 *         &lt;element name="verzoek" type="{http://www.kadaster.nl/schemas/gds2/afgifte-bestandophalen/v20120901}BestandOphalenType"/&gt;
 *       &lt;/sequence&gt;
 *     &lt;/restriction&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "verzoek"
})
@XmlRootElement(name = "BestandOphalenRequest")
public class BestandOphalenRequest {

    @XmlElement(required = true)
    protected BestandOphalenType verzoek;

    /**
     * Gets the value of the verzoek property.
     * 
     * @return
     *     possible object is
     *     {@link BestandOphalenType }
     *     
     */
    public BestandOphalenType getVerzoek() {
        return verzoek;
    }

    /**
     * Sets the value of the verzoek property.
     * 
     * @param value
     *     allowed object is
     *     {@link BestandOphalenType }
     *     
     */
    public void setVerzoek(BestandOphalenType value) {
        this.verzoek = value;
    }

}
